@@ -1,5 +1,6 @@
 from ideaseed.constants import COLOR_NAME_TO_HEX_MAP, C_PRIMARY
 import json
+import webbrowser
 from os import path
 from ideaseed.utils import ask, dye, get_token_cache_filepath
 from typing import *
@@ -72,7 +73,7 @@ def push_to_gkeep(args: Dict[str, Any]) -> None:
     print(" Done.")
 
     # Announce what we'll do
-    color = args["--color"] or 'white'
+    color = args["--color"] or 'White'
     print(
         f"Creating a "
         + dye(' ' + color.lower() + ' ', fg=0x000, bg=COLOR_NAME_TO_HEX_MAP[color])
@@ -81,7 +82,7 @@ def push_to_gkeep(args: Dict[str, Any]) -> None:
 
     # Create the note
     note = keep.createNote(title=args["--title"], text=args["IDEA"])
-    note.color = getattr(ColorValue, args["--color"])
+    note.color = getattr(ColorValue, color)
     note.pinned = True
 
     # Find/create all the labels
@@ -97,3 +98,8 @@ def push_to_gkeep(args: Dict[str, Any]) -> None:
 
     # Beam it up to Google's servers
     keep.sync()
+    
+    # Open the browser
+    if args['--open']:
+        url = f"https://keep.google.com/u/0/#NOTE/{note.id}"
+        webbrowser.open(url)
